var searchData=
[
  ['barpositionmusic',['barPositionMusic',['../structSteinberg_1_1Vst_1_1ProcessContext.html#a9081efe983722f59098a542b149bb07f',1,'Steinberg::Vst::ProcessContext']]],
  ['bassnote',['bassNote',['../structSteinberg_1_1Vst_1_1ChordEvent.html#a4f5c7e14d27cd2000f90c5fca2adb9a7',1,'Steinberg::Vst::ChordEvent']]],
  ['blockid',['blockID',['../structSteinberg_1_1Vst_1_1DataExchangeBlock.html#a9f9919f70a2fc51767a51007a625dd5a',1,'Steinberg::Vst::DataExchangeBlock']]],
  ['blocksize',['blockSize',['../../vstsdk/structSteinberg_1_1Vst_1_1DataExchangeHandler_1_1Config.html#a46e19d5fda11ba7882b319a8bf47cf8d',1,'Steinberg::Vst::DataExchangeHandler::Config']]],
  ['bottom',['bottom',['../../base/structSteinberg_1_1ViewRect.html#a056cba400137ab9db43fdc7da2132a40',1,'Steinberg::ViewRect']]],
  ['buffersareequal',['buffersAreEqual',['../../vstsdk/structSteinberg_1_1Vst_1_1TestDefaults.html#ab601a897082adf69326ab72c789e3471',1,'Steinberg::Vst::TestDefaults']]],
  ['busindex',['busIndex',['../structSteinberg_1_1Vst_1_1RoutingInfo.html#acd2bbbb2eae99e9e00ac1517dbf7958d',1,'Steinberg::Vst::RoutingInfo::busIndex()'],['../structSteinberg_1_1Vst_1_1Event.html#acd2bbbb2eae99e9e00ac1517dbf7958d',1,'Steinberg::Vst::Event::busIndex()']]],
  ['bustype',['busType',['../../vstsdk/classSteinberg_1_1Vst_1_1Bus.html#a19466623a694c883892184cab092ebfc',1,'Steinberg::Vst::Bus::busType()'],['../structSteinberg_1_1Vst_1_1BusInfo.html#a795177c339bd0b25de0ea4189aa6c893',1,'Steinberg::Vst::BusInfo::busType()']]],
  ['bytes',['bytes',['../structSteinberg_1_1Vst_1_1DataEvent.html#ab0e4bfcd0606119dacd07fd9388de747',1,'Steinberg::Vst::DataEvent']]]
];
